@@ -76,17 +76,18 @@ FILE_OPTIONS = {
                          'to false.'),
         cfg.ListOpt('memcache_servers', default=['localhost:11211'],
                     help='Memcache servers in the format of "host:port". '
-                         '(dogpile.cache.memcached and '
-                         'oslo_cache.memcache_pool backends only). '
-                         'If a given host refer to an IPv6 or a given domain '
-                         'refer to IPv6 then you should prefix the given '
-                         'address with the address family (``inet6``) '
+                         'This is used by backends dependent on Memcached.'
+                         'If ``dogpile.cache.memcached`` or '
+                         '``oslo_cache.memcache_pool`` is used and a given '
+                         'host refer to an IPv6 or a given domain refer to '
+                         'IPv6 then you should prefix the given address with'
+                         'the address family (``inet6``) '
                          '(e.g ``inet6[::1]:11211``, '
                          '``inet6:[fd12:3456:789a:1::1]:11211``, '
                          '``inet6:[controller-0.internalapi]:11211``). '
-                         'If the address family is not given then default '
-                         'address family used will be ``inet`` which '
-                         'correspond to IPv4'),
+                         'If the address family is not given then these '
+                         'backends will use the default ``inet`` address '
+                         'family which corresponds to IPv4'),
         cfg.IntOpt('memcache_dead_retry',
                    default=5 * 60,
                    help='Number of seconds memcached server is considered dead'
@@ -116,6 +117,17 @@ FILE_OPTIONS = {
                     help='Global toggle if memcache will be flushed'
                     ' on reconnect.'
                     ' (oslo_cache.memcache_pool backend only).'),
+        cfg.BoolOpt('memcache_sasl_enabled',
+                    default=False,
+                    help='Enable the SASL(Simple Authentication and Security'
+                         'Layer) if the SASL_enable is true, else disable.'),
+        cfg.StrOpt('memcache_username',
+                   default='',
+                   help='the user name for the memcached which SASL enabled'),
+        cfg.StrOpt('memcache_password',
+                   default='',
+                   secret=True,
+                   help='the password for the memcached which SASL enabled'),
         cfg.BoolOpt('tls_enabled',
                     default=False,
                     help='Global toggle for TLS usage when comunicating with'
@@ -146,6 +158,65 @@ FILE_OPTIONS = {
                    ' the TLS context. It should be a string in the OpenSSL'
                    ' cipher list format. If not specified, all OpenSSL enabled'
                    ' ciphers will be available.'),
+        cfg.BoolOpt(
+            'enable_socket_keepalive',
+            default=False,
+            help="Global toggle for the socket keepalive of "
+            "dogpile's pymemcache backend"),
+        cfg.IntOpt(
+            'socket_keepalive_idle',
+            default=1,
+            min=0,
+            help='The time (in seconds) the connection needs to '
+            'remain idle before TCP starts sending keepalive probes. '
+            'Should be a positive integer most greater than zero.'),
+        cfg.IntOpt(
+            'socket_keepalive_interval',
+            default=1,
+            min=0,
+            help='The time (in seconds) between individual keepalive '
+            'probes. Should be a positive integer greater '
+            'than zero.'),
+        cfg.IntOpt(
+            'socket_keepalive_count',
+            default=1,
+            min=0,
+            help='The maximum number of keepalive probes TCP should '
+            'send before dropping the connection. Should be a '
+            'positive integer greater than zero.'),
+        cfg.BoolOpt(
+            'enable_retry_client',
+            default=False,
+            help='Enable retry client mechanisms to handle failure. '
+            'Those mechanisms can be used to wrap all kind of pymemcache '
+            'clients. The wrapper allows you to define how many attempts '
+            'to make and how long to wait between attemots.'),
+        cfg.IntOpt(
+            'retry_attempts',
+            min=1,
+            default=2,
+            help='Number of times to attempt an action before failing.'),
+        cfg.FloatOpt(
+            'retry_delay',
+            default=0,
+            help='Number of seconds to sleep between each attempt.'),
+        cfg.IntOpt(
+            'hashclient_retry_attempts',
+            min=1,
+            default=2,
+            help='Amount of times a client should be tried '
+            'before it is marked dead and removed from the pool in '
+            'the HashClient\'s internal mechanisms.'),
+        cfg.FloatOpt(
+            'hashclient_retry_delay',
+            default=1,
+            help='Time in seconds that should pass between '
+            'retry attempts in the HashClient\'s internal mechanisms.'),
+        cfg.FloatOpt(
+            'dead_timeout',
+            default=60,
+            help='Time in seconds before attempting to add a node '
+            'back in the pool in the HashClient\'s internal mechanisms.'),
     ],
 }
 
